diff --git a/src/plugins/grass/qgsgrassmodule.cpp b/src/plugins/grass/qgsgrassmodule.cpp
index e50001e..b9e9287 100644
--- a/src/plugins/grass/qgsgrassmodule.cpp
+++ b/src/plugins/grass/qgsgrassmodule.cpp
@@ -353,10 +353,29 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
     return;
   }
 
+  // convert encoding of interface description by myself because
+  // Qt doesn't recognize most of codepage name "CPxxx" currently
+  QByteArray enc;
+  QByteArray ifDesc = process.readAllStandardOutput();
+  QRegExp reg( "encoding=\"(.+)\"" );
+  if ( reg.indexIn( ifDesc.split( '\n' )[0] ) != -1 )
+  {
+    enc = reg.cap( 1 ).toLocal8Bit();
+  }
+
+  QTextCodec *codec = QTextCodec::codecForName( enc );
+  if ( !codec )
+  {
+    // treat codepage name that Qt doesn't recognize as System
+    // default encoding
+    codec = QTextCodec::codecForName( "System" );
+    Q_ASSERT( codec );
+  }
+
   QDomDocument gDoc( "task" );
   QString err;
   int line, column;
-  if ( !gDoc.setContent( &process, false, &err, &line, &column ) )
+  if ( !gDoc.setContent( codec->toUnicode( ifDesc ), false, &err, &line, &column ) )
   {
     QString errmsg = tr( "Cannot read module description (%1):" ).arg( mXName )
                      + tr( "\n%1\nat line %2 column %3" ).arg( err ).arg( line ).arg( column );
@@ -1552,12 +1571,15 @@ void QgsGrassModule::readStdout()
   QString line;
   QRegExp rxpercent( "GRASS_INFO_PERCENT: (\\d+)" );
 
+  QTextCodec *codec = QTextCodec::codecForName( "System" );
+  Q_ASSERT( codec );
+
   mProcess.setReadChannel( QProcess::StandardOutput );
   while ( mProcess.canReadLine() )
   {
     //line = QString::fromLocal8Bit( mProcess.readLineStdout().ascii() );
     QByteArray ba = mProcess.readLine();
-    line = QString::fromUtf8( ba ).replace( '\n', "" );
+    line = codec->toUnicode( ba ).replace( '\n', "" );
     //QgsDebugMsg(QString("line: '%1'").arg(line));
 
     // GRASS_INFO_PERCENT is catched here only because of bugs in GRASS,
@@ -1587,12 +1609,14 @@ void QgsGrassModule::readStderr()
   QRegExp rxerror( "GRASS_INFO_ERROR\\(\\d+,\\d+\\): (.*)" );
   QRegExp rxend( "GRASS_INFO_END\\(\\d+,\\d+\\)" );
 
+  QTextCodec *codec = QTextCodec::codecForName( "System" );
+  Q_ASSERT( codec );
 
   while ( mProcess.canReadLine() )
   {
     //line = QString::fromLocal8Bit( mProcess.readLineStderr().ascii() );
     QByteArray ba = mProcess.readLine();
-    line = QString::fromUtf8( ba ).replace( '\n', "" );
+    line = codec->toUnicode( ba ).replace( '\n', "" );
     //QgsDebugMsg(QString("line: '%1'").arg(line));
 
     if ( rxpercent.indexIn( line ) != -1 )
